<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="80px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="汇报编号" prop="reportNo">
            <el-input v-model="dataForm.reportNo" placeholder=""></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="汇报类型" prop="applyType">
            <el-select
              v-model="dataForm.reportType"
              placeholder=""
              filterable
              style="width: 100%"
            >
              <el-option
                v-for="item in reportTypeOptions"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="汇报人员" prop="reportPerson">
            <el-input v-model="dataForm.reportPerson" placeholder=""></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="备注" prop="remark">
            <el-input v-model="dataForm.remark" placeholder=""></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import { getReport, addReport, putReport } from '@/api/quality/report'
import { mapGetters } from 'vuex'
import {getStore, setStore} from '@/util/store'

export default {
  props: {
    reportTypeOptions: {
      type: Array,
      default: () => {
        return []
      }
    }
  },
  data() {
    return {
      visible: false,
      dataForm: {
        id: 0,
        reportNo: '',
        reportType: '',
        reportPerson: '',
        remark: ''
      },
      dataRule: {},
      isSubmit: false
    }
  },
  computed: {
    ...mapGetters(['userInfo'])
  },
  methods: {
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getReport(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        } else {
          let reportPerson = getStore({name: 'reportPerson'})
          this.dataForm.reportPerson = reportPerson||this.userInfo.staffName
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          setStore({
            name: 'reportPerson',
            content: this.dataForm.reportPerson
          })
          if (this.dataForm.id) {
            putReport(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addReport(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
